# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.loggingConfigInsecureListen

Module implementing checks for insecure use of logging.config.listen function.

### Global Attributes

None

### Classes

None

### Functions

checkLoggingConfigListen | Function to check for insecure use of logging.config.listen function.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkLoggingConfigListen

checkLoggingConfigListen(reportError, context, _config)

Function to check for insecure use of logging.config.listen function.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up